==> cms-db_v0.8.1.tar.gz: admin/locales/en/common.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['common'] = array();

# Start: Buttons
$locale['common']['button_ok'] = 'OK';
$locale['common']['button_save'] = 'Save';
$locale['common']['button_cancel'] = 'Cancel';
$locale['common']['button_yes'] = 'Yes';
$locale['common']['button_no'] = 'No';
$locale['common']['button_send'] = 'Send';
$locale['common']['button_reset'] = 'Reset form';
# End: Buttons

# Start: Categories
$locale['common']['desc_pages'] = 'Page Management';
$locale['common']['desc_files'] = 'File Management';
$locale['common']['desc_includes'] = 'Includes';
$locale['common']['desc_settings'] = 'Settings';
$locale['common']['desc_template'] = 'Template/Design';
$locale['common']['desc_space'] = 'Disk Space';
$locale['common']['desc_fileperms'] = 'File Permissions';
$locale['common']['desc_backup'] = 'Backups';
$locale['common']['desc_guestbook'] = 'Guestbook Entries';
$locale['common']['desc_blog'] = 'Blog';
$locale['common']['desc_stats'] = 'Statistics';
$locale['common']['desc_recyclebin'] = 'Recycling Center';
# End: Categories

# Start: Settings
$locale['common']['link_usersettings'] = 'Users';
$locale['common']['link_commonsettings'] = 'Common';
$locale['common']['link_urlsettings'] = 'URL';
$locale['common']['link_ftpsettings'] = 'FTP';
$locale['common']['link_adminsettings'] = 'Appearance';
$locale['common']['link_localesettings'] = 'Language';
$locale['common']['desc_settings-saved'] = 'The settings have been saved.';
# End: Settings

# Start: Errors
$locale['common']['title_error'] = 'Error';
$locale['common']['desc_error-open-file'] = 'Can\'t open the file <i>%s</i>.';
$locale['common']['desc_error-write-file'] = 'Can\'t write to the file <i>%s</i>.';
$locale['common']['desc_error-fileperms'] = 'You don\'t have write permissions for the file <i>%s</i>.';
$locale['common']['desc_error-move-file'] = 'The file couldn\'t be moved.';
$locale['common']['desc_error-input'] = 'You haven\'t filled in all necessary input fields!';
$locale['common']['link_back'] = 'Back';
# End: Errors

# Start: WYMeditor
$locale['common']['wymeditor_align_left'] = 'Aligned left';
$locale['common']['wymeditor_align_right'] = 'Aligned right';
$locale['common']['wymeditor_align_clear'] = 'Stop alignment';
$locale['common']['wymeditor_attributes'] = 'Attributes';
$locale['common']['wymeditor_new_window'] = 'New window';
$locale['common']['wymeditor_new_window_title'] = 'Open a link in a new window';
$locale['common']['wymeditor_anchor'] = 'Anchor (ID)';
$locale['common']['wymeditor_anchor_title'] = 'Add an anchor (id attribute)';
$locale['common']['wymeditor_value'] = 'Value:';
$locale['common']['wymeditor_wrong_element'] = 'This attribute can\'t be assigned to the selected element.';
$locale['common']['wymeditor_error_external'] = 'This function is disabled by default.';
$locale['common']['wymeditor_error_external_why'] = 'Why?';
$locale['common']['wymeditor_error_external_more1'] = 'The attribute to open a link in a new window was removed in XHTML 1.0 Strict.';
$locale['common']['wymeditor_error_external_more2'] = 'Thus a work-around has to be used for opening links in a new window. This work-around requires Javascript and may be broken for users with popup blocker.';
$locale['common']['wymeditor_error_external_more3'] = 'Please use this function very carefully!';
# End: WYMeditor

# Start: Editor
$locale['common']['desc_javascript'] = 'You have to activate Javascript to use the functionality of inserting addresses or the WYSIWYM editor.';
$locale['common']['desc_insert-page'] = 'Pages';
$locale['common']['desc_insert-file'] = 'Files';
# End: Editor

# Start: Autosave
$locale['common']['desc_autosave-version'] = 'This is a previously saved draft of the page.';
$locale['common']['desc_autosave-blog'] = 'This is a previously saved draft of the blog entry.';
$locale['common']['link_discard-changes'] = 'Discard changes';
$locale['common']['link_delete-draft'] = 'Delete draft';
$locale['common']['button_publish'] = 'Publish';
$locale['common']['button_savedraft'] = 'Save draft';
$locale['common']['desc_autosave-saved'] = 'Saved.';
$locale['common']['desc_autosave-saving'] = 'Saving...';
$locale['common']['desc_autosave-skipped'] = 'Save skipped.';
$locale['common']['desc_autosave-next'] = 'Next save in %s seconds...';
$locale['common']['desc_draft'] = 'Draft';
# End: Autosave

# Start: Password
$locale['common']['label_oldpw'] = 'Old password:';
$locale['common']['label_newpw'] = 'New passwort:';
$locale['common']['desc_repeat'] = 'Repeat password:';
$locale['common']['desc_error-invalid-data'] = 'The supplied data is invalid.';
# End: Password

# Start: Dates
$locale['common']['date_day1'] = 'Sunday';
$locale['common']['date_day2'] = 'Monday';
$locale['common']['date_day3'] = 'Tuesday';
$locale['common']['date_day4'] = 'Wednesday';
$locale['common']['date_day5'] = 'Thursday';
$locale['common']['date_day6'] = 'Friday';
$locale['common']['date_day7'] = 'Saturday';
$locale['common']['date_month1'] = 'January';
$locale['common']['date_month2'] = 'February';
$locale['common']['date_month3'] = 'March';
$locale['common']['date_month4'] = 'April';
$locale['common']['date_month5'] = 'May';
$locale['common']['date_month6'] = 'June';
$locale['common']['date_month7'] = 'July';
$locale['common']['date_month8'] = 'August';
$locale['common']['date_month9'] = 'September';
$locale['common']['date_month10'] = 'October';
$locale['common']['date_month11'] = 'November';
$locale['common']['date_month12'] = 'December';
$locale['common']['date_dateformat'] = '+day, +month +d +y';
$locale['common']['date_timeformat'] = '+h:+m';
# End: Dates

# Start: Insert
$locale['common']['desc_cantinsert'] = 'The URL couldn\'t be inserted. Instead, you can copy the destination address either from the link in the list or from the menu on the website.';
# End: Insert

# Start: CSRF Protection Error
$locale['common']['title_csrfprotection'] = 'Invalid or Missing Verification Code';
$locale['common']['desc_csrfprotection'] = 'The verification code for the requested page was not transfered correctly. This could possibly indicate a CSRF attack. Another reason could be a programming error.';
# End: CSRF Protection Error

$locale['common']['label_username'] = 'Username';
$locale['common']['label_password'] = 'Password';

$locale['common']['link_next'] = 'Next';
$locale['common']['link_edit'] = 'edit';
$locale['common']['link_rename'] = 'rename';
$locale['common']['link_delete'] = 'delete';
$locale['common']['desc_action'] = 'Action';

$locale['common']['title_editpage'] = 'Edit Page';

$locale['common']['button_create'] = 'Create';

$locale['common']['link_close'] = 'Close';
?>

==> cms-db_v0.9.tar.gz: admin/locales/en/common.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['common'] = array();

# Start: Buttons
$locale['common']['button_ok'] = 'OK';
$locale['common']['button_save'] = 'Save';
$locale['common']['button_cancel'] = 'Cancel';
$locale['common']['button_yes'] = 'Yes';
$locale['common']['button_no'] = 'No';
$locale['common']['button_send'] = 'Send';
$locale['common']['button_reset'] = 'Reset form';
# End: Buttons

# Start: Categories
$locale['common']['desc_pages'] = 'Page Management';
$locale['common']['desc_files'] = 'File Management';
$locale['common']['desc_includes'] = 'Includes';
$locale['common']['desc_settings'] = 'Settings';
$locale['common']['desc_template'] = 'Design Template';
$locale['common']['desc_space'] = 'Disk Space';
$locale['common']['desc_fileperms'] = 'File Permissions';
$locale['common']['desc_backup'] = 'Backups';
$locale['common']['desc_guestbook'] = 'Guestbook Entries';
$locale['common']['desc_blog'] = 'Blog';
$locale['common']['desc_stats'] = 'Statistics';
$locale['common']['desc_recyclebin'] = 'Recycling Center';
# End: Categories

# Start: Settings
$locale['common']['link_usersettings'] = 'Users';
$locale['common']['link_commonsettings'] = 'Common';
$locale['common']['link_urlsettings'] = 'URL';
$locale['common']['link_updatesettings'] = 'Updates';
$locale['common']['link_adminsettings'] = 'Appearance';
$locale['common']['link_editorsettings'] = 'Editor';
$locale['common']['link_localesettings'] = 'Language';
$locale['common']['desc_settings-saved'] = 'The settings have been saved.';
$locale['common']['label_autoupdate'] = 'Enable automatic check for updates';
$locale['common']['desc_autoupdate'] = 'After each login cms -db will check for updates and notify you whenever a new version is available.';
$locale['common']['desc_updatecheck'] = 'The IP address of your server and the version number of your cms -db installation will be transmitted to the update server. The IP address may be saved in the access logs of the webserver, but none of the data will be saved or even analyzed in any other way.';

# End: Settings

# Start: Errors
$locale['common']['title_error'] = 'Error';
$locale['common']['desc_error-open-file'] = 'The file <i>%s</i> could not be opened.';
$locale['common']['desc_error-write-file'] = 'The file <i>%s</i> could not be written.';
$locale['common']['desc_error-fileperms'] = 'You don\'t have write permissions for the file <i>%s</i>.';
$locale['common']['desc_error-move-file'] = 'The file couldn\'t be moved.';
$locale['common']['link_back'] = 'Back';
# End: Errors

# Start: guestbook / contact errors
$locale['common']['desc_error-input'] = 'Please enter the following mandatory information:';
$locale['common']['desc_error-spamprotection'] = 'The request could not be handled. Please wait at least 10 seconds and try again.';
# End: guestbook / contact errors

# Start: WYMeditor
$locale['common']['wymeditor_stretch_image'] = 'Full width';
$locale['common']['wymeditor_align_left'] = 'Aligned left';
$locale['common']['wymeditor_align_right'] = 'Aligned right';
$locale['common']['wymeditor_align_clear'] = 'Stop alignment';
$locale['common']['wymeditor_attributes'] = 'Attributes';
$locale['common']['wymeditor_new_window'] = 'New window';
$locale['common']['wymeditor_new_window_title'] = 'Open a link in a new window';
$locale['common']['wymeditor_anchor'] = 'Anchor (ID)';
$locale['common']['wymeditor_anchor_title'] = 'Add an anchor (id attribute)';
$locale['common']['wymeditor_value'] = 'Value:';
$locale['common']['wymeditor_wrong_element'] = 'This attribute can\'t be assigned to the selected element.';
$locale['common']['wymeditor_error_external'] = 'This feature is not enabled by the default settings.';
$locale['common']['wymeditor_error_external_why'] = 'Why?';
$locale['common']['wymeditor_error_external_more1'] = 'The possibility to open a link in a new window was removed in the XHTML 1.0 Strict standard.';
$locale['common']['wymeditor_error_external_more2'] = 'Thus a work-around has to be used for opening links in a new window. This work-around requires Javascript and may be broken for users with popup blocker.';
$locale['common']['wymeditor_error_external_more3'] = 'Thus, you should use this feature very carefully!';
# End: WYMeditor

# Start: Editor
$locale['common']['desc_javascript'] = 'You have to activate Javascript to use the functionality of inserting addresses or the WYSIWYM editor.';
$locale['common']['desc_insert-page'] = 'Pages';
$locale['common']['desc_insert-file'] = 'Files';
# End: Editor

# Start: Autosave
$locale['common']['desc_autosave-version'] = 'This is a previously saved draft of the page.';
$locale['common']['desc_autosave-blog'] = 'This is a previously saved draft of the blog entry.';
$locale['common']['link_discard-changes'] = 'Discard changes';
$locale['common']['link_delete-draft'] = 'Delete draft';
$locale['common']['button_publish'] = 'Publish';
$locale['common']['button_savedraft'] = 'Save draft';
$locale['common']['desc_autosave-saved'] = 'Saved.';
$locale['common']['desc_autosave-saving'] = 'Saving...';
$locale['common']['desc_autosave-skipped'] = 'Save skipped.';
$locale['common']['desc_autosave-next'] = 'Next save in %s seconds...';
$locale['common']['desc_draft'] = 'Draft';
# End: Autosave

# Start: Password
$locale['common']['label_oldpw'] = 'Old password:';
$locale['common']['label_newpw'] = 'New passwort:';
$locale['common']['desc_repeat'] = 'Repeat password:';
$locale['common']['desc_error-invalid-data'] = 'The supplied data is invalid.';
# End: Password

# Start: Dates
$locale['common']['date_day1'] = 'Sunday';
$locale['common']['date_day2'] = 'Monday';
$locale['common']['date_day3'] = 'Tuesday';
$locale['common']['date_day4'] = 'Wednesday';
$locale['common']['date_day5'] = 'Thursday';
$locale['common']['date_day6'] = 'Friday';
$locale['common']['date_day7'] = 'Saturday';
$locale['common']['date_month1'] = 'January';
$locale['common']['date_month2'] = 'February';
$locale['common']['date_month3'] = 'March';
$locale['common']['date_month4'] = 'April';
$locale['common']['date_month5'] = 'May';
$locale['common']['date_month6'] = 'June';
$locale['common']['date_month7'] = 'July';
$locale['common']['date_month8'] = 'August';
$locale['common']['date_month9'] = 'September';
$locale['common']['date_month10'] = 'October';
$locale['common']['date_month11'] = 'November';
$locale['common']['date_month12'] = 'December';
$locale['common']['date_dateformat'] = '+day, +month +d +y';
$locale['common']['date_timeformat'] = '+h:+m';
# End: Dates

# Start: Insert
$locale['common']['desc_cantinsert'] = 'The URL couldn\'t be inserted. Instead, you can copy the destination address either from the link in the list or from the menu on the website.';
# End: Insert

# Start: CSRF Protection Error
$locale['common']['title_csrfprotection'] = 'Invalid or Missing Verification Code';
$locale['common']['desc_csrfprotection'] = 'The verification code for the requested page was not transfered correctly. This could possibly indicate a CSRF attack. Another reason could be a programming error.';
# End: CSRF Protection Error

# Start: License Info (firstrun.php + version.php)
$locale['common']['licensenotes1'] = 'This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.';
$locale['common']['licensenotes2'] = 'This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.';
$locale['common']['licensenotes3'] = 'You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.';
# End: License Info

$locale['common']['label_username'] = 'Username';
$locale['common']['label_password'] = 'Password';

$locale['common']['link_next'] = 'Next';
$locale['common']['link_open'] = 'open';
$locale['common']['link_edit'] = 'edit';
$locale['common']['link_rename'] = 'rename';
$locale['common']['link_delete'] = 'delete';
$locale['common']['desc_action'] = 'Action';

$locale['common']['title_editpage'] = 'Edit Page';

$locale['common']['button_create'] = 'Create';

$locale['common']['link_close'] = 'Close';
?>
